#!usr/bin/env python3
# coding:utf-8

# 系统
SYSTEM = 'System'
# 文本
TEXT = 'Text'
# 视频
VIDEO = 'Video'

class Message(object):

    def __init__(self, ai):
        self.ai = ai
        self.text = None
        self.id = None

    @property
    def chat(self):
        """
        消息所在的聊天会话，即:

            对于自己发送的消息，为消息的接收者；
            对于别人发送的消息，为消息的发送者。
        """
        print('Message--chat()')
        # if self.raw.get('FromUserName') == self.bot.self.user_name:
        #     return self.receiver
        # else:
        #     return self.sender


#!usr/bin/env python3
# coding:utf-8

class MessageConfig(object):

    def __init__(self, ai, func, except_self):
        self.ai = ai
        self.func = func
        self.except_self = except_self
        print('消息配置')


#!usr/bin/env python3
# coding:utf-8

from .message import SYSTEM

class Registered(list):
    def __init__(self, bot):
        """
        保存当前机器人所有已注册的消息配置

        :param bot: 所属的机器人
        """
        super(Registered, self).__init__()
        self.bot = bot

    def getConfig(self, msg):
        for conf in self[::-1]:
            return conf


    def get_config(self, msg):
        """
        获取给定消息的注册配置。每条消息仅匹配一个注册配置，后注册的配置具有更高的匹配优先级。

        :param msg: 给定的消息
        :return: 匹配的回复配置
        """

        for conf in self[::-1]:

            if not conf.enabled or (conf.except_self and msg.sender == self.bot.self):
                continue

            if conf.msg_types and msg.type not in conf.msg_types:
                continue
            elif conf.msg_types is None and msg.type == SYSTEM:
                continue

            if conf.chats is None:
                return conf

            for chat in conf.chats:
                if (isinstance(chat, type) and isinstance(msg.chat, chat)) or chat == msg.chat:
                    return conf


#!usr/bin/env python
# coding:utf-8

import logging
from threading import Thread
from .messages import Registered,Message,MessageConfig

logger = logging.getLogger(__name__)

class YBAI(object):

    def __init__(self):
        print('初始化AI')

        self.setup()
        pass

    def setup(self):
        print('设置配置')
        self.reg = Registered(self)
        pass

    @property
    def receiveMsgHandle(self, msg):

        conf = self.reg.getConfig(msg)
        print(conf)
        if not conf:
            return
        def process():
            try:
               res = conf.func(msg)
               if res:
                   print('又返回结果')
            except:
                print('异常发送')
        Thread(target=process, daemon=True).start()


    def register(self,except_self = None):
        def do_register(func):
            self.reg.append(MessageConfig(ai=self,func=func,except_self=except_self))
            print('收到注册消息')
            return func
            pass
        print('注册事件')
        return do_register
        pass

    def start(self):
        print('开始')
        """
        开始消息监听和处理 (登陆后会自动开始)
        """
        pass

    def stop(self):
        print('stop')
        """
        停止消息监听和处理 (登出后会自动停止)
        """
        pass

    def _cleanup(self):
        print('清空')
        pass


#!/usr/bin/env python3
# coding: utf-8

"""


注释


"""
import sys
sys.path.append(".") #.表示当前目录

from .api import *

__title__ = 'ybai'
__version__ = '0.0.4'
__author__ = 'Yinbing'
__license__ = 'MIT'
__copyright__ = '2017, Yinbing'

version_details = 'ybai {ver} from {path} (python {pv.major}.{pv.minor}.{pv.micro})'.format(
    ver=__version__, path=__path__[0], pv=sys.version_info)
